<?php

include("code.php");

function test_lang($lang, $language = null, $line = null)
{
  global $code;
  if (!isset($language)) $language = $lang;
  else $as = "as $language";

  $snippet = <<<EOF
<h1>$lang $as</h1>
<p>This *is* what some <code>$lang</code> code looks like:</p>
<pre lang='$language' line="$line"> \t \r
$code[$lang]
</pre>
EOF;

  return $snippet;
}

function test_all()
{
  $content = '';
  $content .= test_lang('php');
  $content .= test_lang('lisp', null, 1);
  $content .= test_lang('java', null, 1);
  $content .= test_lang('xml');
  $content .= test_lang('html', 'html4strict');
  $content .= test_lang('html', 'xml', 18);
  $content .= test_lang('ocaml');
  $content .= test_lang('ruby', null, 18);
  $content .= test_lang('ruby');
  $content .= test_lang('rails');

  echo apply_filters("the_content", $content);
}

?>

<html>
<head>
<title>WP-Syntax Test Page</title>
<style>

.wp_syntax { 
  color: #100;
  background-color: #f9f9f9;
  border: 1px solid silver;
  margin: 0 0 1.5em 0;
  overflow: auto;
}

/* IE FIX */
.wp_syntax { 
  overflow-x: auto;
  overflow-y: hidden;
  padding-bottom: expression(this.scrollWidth > this.offsetWidth ? 15 : 0);
  width: 100%;
}

.wp_syntax table {
  border-collapse: collapse;
}

.wp_syntax div, .wp_syntax td { 
  vertical-align: top;
  padding: 2px 4px;
}

.wp_syntax .line_numbers {
  text-align: right;
  background-color: #def;
  color: gray;
  overflow: visible;
}

/* potential overrides for other styles */
.wp_syntax pre {
  margin: 0;
  width: auto;
  float: none;
  clear: none;
  overflow: visible;
}

</style>
</head>

<body>
<div style="width:50%;">
<?php
add_filter('the_content', 'pre_killer');   // bad if run before GeSHi
add_filter('the_content', 'amp_exposer');  // bad if run after GeSHi

if (file_exists("filters/filters.php"))
{
  include("filters/filters.php");
}
include("../wp-syntax.php");
test_all();
?>
</div>
</body>
</html>


<?php

function amp_exposer($content)
{
    return str_replace("&", "&amp;", $content);
}

function pre_killer($content)
{
    return preg_replace("/<(\/)?pre([^>]*)>/", "[$1pre$2]", $content);
}

/*
 * === WORDPRESS STUBS ===
 */
function remove_filter($tag, $function_to_remove, $priority = 10)
{
    return true;
}

function add_filter($tag, $function_to_add, $priority = 10, $accepted_args = 1) 
{
    global $test_filter;

    $test_filter[$tag][$priority][] = $function_to_add;
    $test_filter[$tag][$priority] = array_unique($test_filter[$tag][$priority]);

    return true;
}

function apply_filters($tag, $string)
{
    global $test_filter;

    if (!isset($test_filter[$tag])) return $string;

    uksort($test_filter[$tag], "strnatcasecmp");

    foreach ($test_filter[$tag] as $priority => $functions) 
    {
        if (is_null($functions)) continue;

        foreach($functions as $function) 
        {
            $string = call_user_func_array($function, array($string));
        }
    }
    return $string;
}

?>

